@@ -1,6 +1,7 @@
 #!/usr/bin/env node
 'use strict';
 
+const debug = require('atom-debugger');
 const create = require('../src/create.js');
 const build = require('../src/webpack/pack.js');
 const server = require('../src/server.js');
@@ -26,6 +27,11 @@ if (!arg || arg === 'help') {
 } else if (arg === 'testSsr') {
     var url = process.argv[3];
     testSsr(url);
+} else if (arg === 'debug') {
+    var config = {
+        enableHeadless: true
+    };
+    debug.api.startServerAndLaunchDevtool(null, config);
 } else {
     console.log(help);
     process.exit();
